api.events.v1.test_helpers.nids package — Argus-Toolbelt 1.0 documentation

# api.events.v1.test_helpers.nids package

## Submodules

## api.events.v1.test_helpers.nids.find_n_i_d_s_events module

`api.events.v1.test_helpers.nids.find_n_i_d_s_events.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids/search, respond with HTTP 403

`api.events.v1.test_helpers.nids.find_n_i_d_s_events.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids/search, respond with HTTP 404

`api.events.v1.test_helpers.nids.find_n_i_d_s_events.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids/search, respond with HTTP 200

`api.events.v1.test_helpers.nids.find_n_i_d_s_events.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids/search, respond with HTTP 401

## api.events.v1.test_helpers.nids.list_n_i_d_s_events module

`api.events.v1.test_helpers.nids.list_n_i_d_s_events.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids, respond with HTTP 403

`api.events.v1.test_helpers.nids.list_n_i_d_s_events.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids, respond with HTTP 404

`api.events.v1.test_helpers.nids.list_n_i_d_s_events.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids, respond with HTTP 200

`api.events.v1.test_helpers.nids.list_n_i_d_s_events.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/events/v1/nids, respond with HTTP 401

## Module contents